<template>
  <div>
    <el-dialog
        title="巡检"
        v-model="dialogVisitable"
        width="400px"
        @close="cancel"
    >
      <el-form :model="form" :rules="rules" ref="formRef" label-width="120px">
        <el-row>
          <el-col :span="24">
            <el-form-item label="设备名称" prop="deviceName">
              <el-input v-model="form.deviceName" placeholder="请输入设备名称" maxlength="30" disabled/>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="地点" prop="location">
              <el-input v-model="form.location" placeholder="请输入地点" maxlength="30" disabled/>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="附件" prop="taxTrans">
              <fileUpload
                  :statusType="0"
                  ref="beforeProductionRef"
                  :fileSize="1024"
                  :fileType="['mp3', 'mp4', 'avi', 'mov', 'mkv']"
                  :limit="10"
                  :drag="false"
                  v-model:modelValue="form.storageBlobDTO"
              >
              </fileUpload>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="巡检人" prop="scannerName">
              <el-input v-model="form.scannerName" disabled placeholder="请输入" />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="巡检时间" prop="scanTime">
              <el-input v-model="form.scanTime" disabled placeholder="请输入" />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button @click="cancel">取消</el-button>
          <el-button type="primary" @click="submitForm">保存</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup>
import { reactive, ref } from "vue";
import {ElMessage} from "element-plus";
import fileUpload from "@/components/FileUpload/index.vue";
import {uploadInspectionTask} from "@/api/inspectionManagement/index.js";
import useUserStore from "@/store/modules/user.js";
import {addOrEditQrCodeRecord} from "@/api/inspectionUpload/index.js";

const emit = defineEmits(['closeDia']);
const dialogVisitable = ref(false);
const { proxy } = getCurrentInstance()
const storageBlobDTO = ref([]);
const beforeProductionRef = ref(null);
const userStore = useUserStore();
const userInfo = ref({});

function getCurrentDateTime() {
  const now = new Date();
  const year = now.getFullYear();
  const month = String(now.getMonth() + 1).padStart(2, '0');
  const day = String(now.getDate()).padStart(2, '0');
  const hours = String(now.getHours()).padStart(2, '0');
  const minutes = String(now.getMinutes()).padStart(2, '0');
  const seconds = String(now.getSeconds()).padStart(2, '0');
  return `${year}-${month}-${day} ${hours}:${minutes}:${seconds}`;
}
const data = reactive({
  form: {
    deviceName: '',
    location: '',
    scannerName: '',
    scannerId: '',
    scanTime: '',
    qrCode: {
      id: ''
    }
  },
  rules: {
    deviceName: [{ required: true, message: '请输入设备名称', trigger: 'blur' }],
    location: [{ required: true, message: '请输入地点', trigger: 'blur' }]
  }
})
const { form, rules } = toRefs(data)

// 调用函数
const currentDateTime = getCurrentDateTime();

// 获取用户信息
onMounted(async () => {
  let res = await userStore.getInfo();
  userInfo.value = res.user;
  form.value.scannerName = userInfo.value.nickName
  form.value.scannerId = userInfo.value.userId
  form.value.scanTime = currentDateTime
});

// 打开弹框
const openDialog = async (row) => {
  dialogVisitable.value = true;
  form.value.deviceName = row.deviceName
  form.value.location = row.location
  form.value.qrCodeId = row.qrCodeId
};
const submitForm = async () => {
  form.value.qrCode.id = form.value.qrCodeId
  await addOrEditQrCodeRecord({...form.value});
  cancel()
  ElMessage.success("提交成功");
};
// 关闭合并表单
const cancel = () => {
  proxy.resetForm("formRef");
  dialogVisitable.value = false;
  emit("closeDia");
};
defineExpose({ openDialog });
</script>

<style scoped lang="scss">
.upload-container {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 20px;
  border: 1px solid #dcdfe6;
  box-sizing: border-box;
  .form-container {
    flex: 1;
    width: 100%;
    margin-bottom: 20px;
  }
}
.title {
  font-size: 14px;
  color: #165dff;
  line-height: 20px;
  font-weight: 600;
  padding-left: 10px;
  position: relative;
  margin: 6px 0;
}
.title::before {
  content: "";
  position: absolute;
  left: 0;
  top: 3px; /* 调整垂直位置 */
  width: 4px; /* 小数条宽度 */
  height: 14px; /* 小数条高度 */
  background-color: #165dff; /* 蓝色 */
}
</style>
